@@ -174,7 +174,7 @@ class ParametersCOSIM:
     def makeGenericIOPortFiles(self, CoilSections, CurrentFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
                                t_0 = [0, 2e-5], t_end = [2e-5, 0.5], t_step_max = [[1e-5, 1e-5], [1e-5, 1e-5]],
                                relTolerance = [1e-4, None], absTolerance = [1, None], executionOrder = [1, 2],
-                               executeCleanRun = [True, True], N_LEDET = 1, SimulationNumber = [0], DistinctMagnets = 1):
+                               executeCleanRun = [True, True], N_LEDET = 1, SimulationNumber = [0], DistinctMagnets = 1, PSPICEinitialConditions = []):
 
         # Components which are used in the Ports
         Components = ["L", "CoilSections"]  # [0] = PSpice, [1]=LEDET
@@ -243,6 +243,7 @@ class ParametersCOSIM:
         with open(filename, 'r') as f:
             data = json.load(f)
             data["solverPath"] = PSpiceExecutable
+            data["initialConditions"] = PSPICEinitialConditions
 
         try:
             os.remove(filename)
